<?php

if ( ! function_exists( 'sante_nav_item_classes' ) ) {
	/**
	 * Function that add additional classes for menu items
	 *
	 * @param array    $classes The CSS classes that are applied to the menu item's `<li>` element.
	 * @param WP_Post  $item The current menu item.
	 * @param stdClass $args An object of wp_nav_menu() arguments.
	 * @param int      $depth Depth of menu item. Used for padding.
	 *
	 * @return array
	 */
	function sante_nav_item_classes( $classes, $item, $args, $depth ) {
		
		if ( $depth == 0 && in_array( 'menu-item-has-children', $item->classes ) ) {
			$classes[] = 'qodef-menu-item--narrow';
		}
		
		return $classes;
	}
	
	add_filter( 'nav_menu_css_class', 'sante_nav_item_classes', 10, 4 );
}

if ( ! function_exists( 'sante_add_nav_item_icon' ) ) {
	/**
	 * Function that add additional element after the menu title
	 *
	 * @param string   $title The menu item's title.
	 * @param WP_Post  $item  The current menu item.
	 * @param stdClass $args  An object of wp_nav_menu() arguments.
	 * @param int      $depth Depth of menu item. Used for padding.
	 *
	 * @return string
	 */
	function sante_add_nav_item_icon( $title, $item, $args, $depth ) {

		if ( in_array( 'menu-item-has-children', $item->classes ) && sante_is_installed('framework') ) {
			$title .= qode_framework_icons()->get_specific_icon_from_pack( 'chevron-right', 'linear-icons' );
		}
		
		return $title;
	}
	
	add_filter( 'nav_menu_item_title', 'sante_add_nav_item_icon', 10, 4 );
}