<?php

if ( ! function_exists( 'sante_is_page_title_enabled' ) ) {
	/**
	 * Function that check is module enabled
	 */
	function sante_is_page_title_enabled() {
	    if( ! sante_is_installed('core') &&  is_single() ){
	        return false;
        } else {
            return apply_filters('sante_filter_enable_page_title', true);
        }
	}
}

if ( ! function_exists( 'sante_load_page_title' ) ) {
	/**
	 * Function which loads page template module
	 */
	function sante_load_page_title() {

		if ( sante_is_page_title_enabled() ) {
			// Include title template
			echo apply_filters( 'sante_filter_title_template', sante_get_template_part( 'title', 'templates/title' ) );
		}
	}
	
	add_action( 'sante_action_page_title_template', 'sante_load_page_title' );
}

if ( ! function_exists( 'sante_get_page_title_classes' ) ) {
	/**
	 * Function that return classes for page title area
	 *
	 * @return string
	 */
	function sante_get_page_title_classes() {
		$classes = apply_filters( 'sante_filter_page_title_classes', array() );
		
		return implode( ' ', $classes );
	}
}

if ( ! function_exists( 'sante_get_page_title_text' ) ) {
	/**
	 * Function that returns current page title text
	 */
	function sante_get_page_title_text() {
		$title = get_the_title( sante_get_page_id() );
		
		if ( ( is_home() && is_front_page() ) ) {
			$title = get_option( 'blogname' );
		} elseif ( is_tag() ) {
			$title = single_term_title( '', false ) . esc_html__( ' Tag', 'sante' );
		}elseif ( is_singular( 'post' ) ){
            $title = esc_html__( 'Blog single', 'sante' );
        } elseif ( is_date() ) {
			$title = get_the_time( 'F Y' );
		} elseif ( is_author() ) {
			$title = esc_html__( 'Author: ', 'sante' ) . get_the_author();
		} elseif ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_archive() ) {
			$title = esc_html__( 'Archive', 'sante' );
		} elseif ( is_search() ) {
			$title = esc_html__( 'Search results for: ', 'sante' ) . get_search_query();
		} elseif ( is_404() ) {
			$title = esc_html__( '404 - Page not found', 'sante' );
		}
		
		return apply_filters( 'sante_filter_page_title_text', $title );
	}
}
