<?php
/**
 * Product quantity inputs
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/quantity-input.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.8.0
 *
 * @var bool   $readonly If the input should be set to readonly mode.
 * @var string $type     The input type attribute.
 */

defined( 'ABSPATH' ) || exit;

if ( ! isset ( $input_id ) ) {
	$input_id = uniqid( 'quantity_' );
}

if ( $max_value && $min_value === $max_value ) {
	?>
	<div class="qodef-quantity-buttons quantity hidden">
		<input type="hidden" id="<?php echo esc_attr( $input_id ); ?>" class="qty" name="<?php echo esc_attr( $input_name ); ?>" value="<?php echo esc_attr( $min_value ); ?>" />
	</div>
	<?php
} else {
	/* translators: %s: Quantity. */
	$label = ! empty( $args['product_name'] ) ? sprintf( esc_html__( '%s quantity', 'sante' ), wp_strip_all_tags( $args['product_name'] ) ) : esc_html__( 'Quantity', 'sante' );
	?>
	<div class="qodef-quantity-buttons quantity">
		<?php
		/**
		 * Hook to output something before the quantity input field.
		 *
		 * @since 7.2.0
		 */
		do_action( 'woocommerce_before_quantity_input_field' );
		?>
		<label class="screen-reader-text" for="<?php echo esc_attr( $input_id ); ?>"><?php echo esc_attr( $label ); ?></label>
		<span class="qodef-quantity-minus">
            <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                 width="8.36px" height="4.875px" viewBox="0 0 8.36 4.875" enable-background="new 0 0 8.36 4.875" xml:space="preserve">
                <g>
                    <path fill="#2F3327" d="M3.987,4.792L0.084,0.888C0.034,0.838,0,0.762,0,0.695c0-0.067,0.034-0.143,0.084-0.193l0.418-0.418
                        C0.553,0.034,0.62,0,0.695,0c0.067,0,0.143,0.034,0.193,0.084L4.18,3.376l3.292-3.292C7.522,0.034,7.598,0,7.665,0
                        c0.067,0,0.143,0.034,0.193,0.084l0.418,0.418c0.05,0.05,0.084,0.126,0.084,0.193S8.327,0.838,8.276,0.888L4.373,4.792
                        c-0.05,0.05-0.126,0.084-0.193,0.084S4.038,4.842,3.987,4.792z"/>
                </g>
            </svg>
        </span>
		<input
			type="<?php echo apply_filters( 'sante_filter_woo_quantity_input_type', 'text' ); ?>"
			<?php echo esc_attr( $readonly ) ? 'readonly="readonly"' : ''; ?>
			id="<?php echo esc_attr( $input_id ); ?>"
			class="<?php echo esc_attr( join( ' ', (array) $classes ) ); ?> qodef-quantity-input"
			name="<?php echo esc_attr( $input_name ); ?>"
			value="<?php echo esc_attr( ! empty( $input_value ) ? $input_value : 0 ); ?>"
			aria-label="<?php esc_attr_e( 'Product quantity', 'sante' ); ?>"
			size="4"
			data-min="<?php echo esc_attr( $min_value ); ?>"
			data-max="<?php echo esc_attr( 0 < $max_value ? $max_value : '' ); ?>"
			data-step="<?php echo esc_attr( $step ); ?>"
			<?php if ( ! $readonly ) : ?>
				placeholder="<?php echo esc_attr( $placeholder ); ?>"
				inputmode="<?php echo esc_attr( $inputmode ); ?>"
				autocomplete="<?php echo esc_attr( isset( $autocomplete ) ? $autocomplete : 'on' ); ?>"
			<?php endif; ?>
		/>
		<span class="qodef-quantity-plus">
            <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                 width="8.36px" height="4.875px" viewBox="0 0 8.36 4.875" enable-background="new 0 0 8.36 4.875" xml:space="preserve">
                <g>
                    <path fill="#2F3327" d="M4.373,0.084l3.903,3.903C8.327,4.038,8.36,4.113,8.36,4.18S8.327,4.323,8.276,4.373L7.858,4.792
                        c-0.05,0.05-0.118,0.084-0.193,0.084c-0.067,0-0.143-0.034-0.193-0.084L4.18,1.5L0.888,4.792c-0.05,0.05-0.126,0.084-0.193,0.084
                        S0.553,4.842,0.502,4.792L0.084,4.373C0.034,4.323,0,4.247,0,4.18s0.034-0.143,0.084-0.193l3.903-3.903C4.038,0.034,4.113,0,4.18,0
                        S4.323,0.034,4.373,0.084z"/>
                </g>
            </svg>
        </span>
		<?php
		/**
		 * Hook to output something after quantity input field
		 *
		 * @since 3.6.0
		 */
		do_action( 'woocommerce_after_quantity_input_field' );
		?>
	</div>
	<?php
}
